==> dcl-5.2C.tar.gz: dcl-5.2C/src/grph1/szpack/szqtxw.c <==
/* szqtxw.f -- translated by f2c (version 19990503).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "f2c.h"

/* Table of constant values */

static integer c__1 = 1;

/* ----------------------------------------------------------------------- */
/*     TEXT WIDTH AND HEIGHT INQUIRY */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int szqtxw_(char *chars, integer *nc, real *wxch, real *wych,
	 ftnlen chars_len)
{
    /* Initialized data */

    static integer ncntz = 0;

    /* System generated locals */
    integer i__1;
    real r__1, r__2;
    char ch__1[1];

    /* Local variables */
    static integer ichk;
    extern integer lenc_(char *, ftnlen);
    extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
    extern integer isgc_(char *, ftnlen);
    static char csub[1];
    static integer nctl, ncnt, nchz, isub, msub, nsub;
    static char csup[1], crst[1];
    static integer isup, irst, msup, nsup, mrst, n, nchar;
    static real rfact, small;
    static logical lcntl;
    static real shift, dz;
    extern integer indxcf_(char *, integer *, integer *, char *, ftnlen, 
	    ftnlen);
    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen);
    extern integer nindxc_(char *, integer *, integer *, char *, ftnlen, 
	    ftnlen);
    extern /* Subroutine */ int sglget_(char *, logical *, ftnlen), msgdmp_(
	    char *, char *, char *, ftnlen, ftnlen, ftnlen), sgrget_(char *, 
	    real *, ftnlen);
    static integer id1, id2, id3, idxsub, ndxsub, idxsup;
    extern /* Subroutine */ int szfint_(integer *);
    static integer idxrst, ndxsup;
    extern /* Subroutine */ int szqfnw_(real *, real *);
    static real wx1[256], wx2[256];
    static integer ich, nch, idx;

/*     / GET FONT INFORMATION / */
    szfint_(&ncnt);
    if (ncntz != ncnt) {
	szqfnw_(wx1, wx2);
	ncntz = ncnt;
    }
    nchz = lenc_(chars, chars_len);
/*     / CHECK LCNTL OPTION / */
    sglget_("LCNTL", &lcntl, (ftnlen)5);
    if (lcntl) {
/*       / CONTROL CHARACTERS ARE EFFECTIVE / */
	sgiget_("ISUP", &isup, (ftnlen)4);
	sgiget_("ISUB", &isub, (ftnlen)4);
	sgiget_("IRST", &irst, (ftnlen)4);
	sgrget_("SMALL", &small, (ftnlen)5);
	sgrget_("SHIFT", &shift, (ftnlen)5);
	csgi_(ch__1, (ftnlen)1, &isup);
	*(unsigned char *)csup = *(unsigned char *)&ch__1[0];
	csgi_(ch__1, (ftnlen)1, &isub);
	*(unsigned char *)csub = *(unsigned char *)&ch__1[0];
	csgi_(ch__1, (ftnlen)1, &irst);
	*(unsigned char *)crst = *(unsigned char *)&ch__1[0];
	*nc = 0;
	nctl = 0;
	nsup = 0;
	nsub = 0;
	ichk = 0;
	msup = nindxc_(chars, &nchz, &c__1, csup, chars_len, (ftnlen)1);
	msub = nindxc_(chars, &nchz, &c__1, csub, chars_len, (ftnlen)1);
	mrst = nindxc_(chars, &nchz, &c__1, crst, chars_len, (ftnlen)1);
	if (mrst != msup + msub) {
	    msgdmp_("E", "SZQTXW", "CONTROL CHARACTERS ARE NOT IN GOOD AGREE"
		    "MENT.", (ftnlen)1, (ftnlen)6, (ftnlen)45);
	}
L10:
	id1 = ichk + 1;
	id2 = nchz;
	nchar = id2 - id1 + 1;
	idxrst = indxcf_(chars + (id1 - 1), &nchar, &c__1, crst, id2 - (id1 - 
		1), (ftnlen)1);
	if (idxrst > 0) {
	    id3 = id1 + idxrst - 1;
	    ndxsup = nindxc_(chars + (id1 - 1), &idxrst, &c__1, csup, id3 - (
		    id1 - 1), (ftnlen)1);
	    ndxsub = nindxc_(chars + (id1 - 1), &idxrst, &c__1, csub, id3 - (
		    id1 - 1), (ftnlen)1);
	    if (ndxsup == 1 != (ndxsub == 1)) {
		++nctl;
		if (ndxsup == 1) {
		    idxsup = indxcf_(chars + (id1 - 1), &idxrst, &c__1, csup, 
			    id3 - (id1 - 1), (ftnlen)1);
		    nch = idxrst - idxsup - 1;
		    if (nch >= 1) {
			nsup += nch;
		    } else {
			msgdmp_("E", "SZQTXW", "NO VALID SUP CHARACTER.", (
				ftnlen)1, (ftnlen)6, (ftnlen)23);
		    }
		} else if (ndxsub == 1) {
		    idxsub = indxcf_(chars + (id1 - 1), &idxrst, &c__1, csub, 
			    id3 - (id1 - 1), (ftnlen)1);
		    nch = idxrst - idxsub - 1;
		    if (nch >= 1) {
			nsub += nch;
		    } else {
			msgdmp_("E", "SZQTXW", "NO VALID SUB CHARACTER.", (
				ftnlen)1, (ftnlen)6, (ftnlen)23);
		    }
		}
		ichk += idxrst;
	    } else {
		msgdmp_("E", "SZQTXW", "CONTROL CHARACTERS ARE NOT IN GOOD A"
			"GREEMENT.", (ftnlen)1, (ftnlen)6, (ftnlen)45);
	    }
	}
	if (! (idxrst == 0 || ichk == nchz)) {
	    goto L10;
	}
/* Computing MAX */
	r__1 = .5f, r__2 = shift + small / 2;
	dz = dmax(r__1,r__2) - .5f;
	rfact = 1.f;
	*wxch = 0.f;
	i__1 = nchz;
	for (n = 1; n <= i__1; ++n) {
	    ich = isgc_(chars + (n - 1), (ftnlen)1);
	    idx = ich + 1;
	    if (ich == isup || ich == isub) {
		rfact = small;
		goto L20;
	    } else if (ich == irst) {
		rfact = 1.f;
		goto L20;
	    }
	    *wxch += (wx2[idx - 1] - wx1[idx - 1]) / 24.f * rfact;
L20:
	    ;
	}
	*wych = 1.f;
	if (nsup >= 1) {
	    *wych += dz;
	}
	if (nsub >= 1) {
	    *wych += dz;
	}
    } else {
/*       / CONTROL CHARACTERS ARE NOT EFFECTIVE / */
	*wxch = 0.f;
	i__1 = nchz;
	for (n = 1; n <= i__1; ++n) {
	    idx = isgc_(chars + (n - 1), (ftnlen)1) + 1;
	    *wxch += (wx2[idx - 1] - wx1[idx - 1]) / 24.f;
/* L30: */
	}
	*wych = 1.f;
    }
    return 0;
} /* szqtxw_ */

==> dcl-6.0.2-C.tar.gz: dcl-6.0.2-C/src/grph1/szpack/szqtxw.c <==
/*  -- translated by f2c (version 20100827).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static integer c__1 = 1;

/* ----------------------------------------------------------------------- */
/*     TEXT WIDTH AND HEIGHT INQUIRY */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int szqtxw_(char *chars, integer *nc, real *wxch, real *wych,
	 ftnlen chars_len)
{
    /* Initialized data */

    static integer ncntz = 0;

    /* System generated locals */
    integer i__1;
    real r__1, r__2;
    char ch__1[1];

    /* Local variables */
    static integer n;
    static real dz;
    static integer id1, id2, id3;
    static real wx1[256], wx2[256];
    static integer ich, nch, idx, ichk;
    extern integer lenc_(char *, ftnlen);
    extern /* Character */ VOID csgi_(char *, ftnlen, integer *);
    extern integer isgc_(char *, ftnlen);
    static char csub[1];
    static integer nctl, ncnt, nchz, isub, msub, nsub;
    static char csup[1], crst[1];
    static integer isup, irst, msup, nsup, mrst, nchar;
    static real rfact, small;
    static logical lcntl;
    static real shift;
    extern integer indxcf_(char *, integer *, integer *, char *, ftnlen, 
	    ftnlen);
    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen);
    extern integer nindxc_(char *, integer *, integer *, char *, ftnlen, 
	    ftnlen);
    extern /* Subroutine */ int sglget_(char *, logical *, ftnlen), msgdmp_(
	    char *, char *, char *, ftnlen, ftnlen, ftnlen), sgrget_(char *, 
	    real *, ftnlen);
    static integer idxsub, ndxsub, idxsup;
    extern /* Subroutine */ int szfint_(integer *);
    static integer idxrst, ndxsup;
    extern /* Subroutine */ int szqfnw_(real *, real *);

/*     / GET FONT INFORMATION / */
    szfint_(&ncnt);
    if (ncntz != ncnt) {
	szqfnw_(wx1, wx2);
	ncntz = ncnt;
    }
    nchz = lenc_(chars, chars_len);
/*     / CHECK LCNTL OPTION / */
    sglget_("LCNTL", &lcntl, (ftnlen)5);
    if (lcntl) {
/*       / CONTROL CHARACTERS ARE EFFECTIVE / */
	sgiget_("ISUP", &isup, (ftnlen)4);
	sgiget_("ISUB", &isub, (ftnlen)4);
	sgiget_("IRST", &irst, (ftnlen)4);
	sgrget_("SMALL", &small, (ftnlen)5);
	sgrget_("SHIFT", &shift, (ftnlen)5);
	csgi_(ch__1, (ftnlen)1, &isup);
	*(unsigned char *)csup = *(unsigned char *)&ch__1[0];
	csgi_(ch__1, (ftnlen)1, &isub);
	*(unsigned char *)csub = *(unsigned char *)&ch__1[0];
	csgi_(ch__1, (ftnlen)1, &irst);
	*(unsigned char *)crst = *(unsigned char *)&ch__1[0];
	*nc = 0;
	nctl = 0;
	nsup = 0;
	nsub = 0;
	ichk = 0;
	msup = nindxc_(chars, &nchz, &c__1, csup, chars_len, (ftnlen)1);
	msub = nindxc_(chars, &nchz, &c__1, csub, chars_len, (ftnlen)1);
	mrst = nindxc_(chars, &nchz, &c__1, crst, chars_len, (ftnlen)1);
	if (mrst != msup + msub) {
	    msgdmp_("E", "SZQTXW", "CONTROL CHARACTERS ARE NOT IN GOOD AGREE"
		    "MENT.", (ftnlen)1, (ftnlen)6, (ftnlen)45);
	}
L10:
	id1 = ichk + 1;
	id2 = nchz;
	nchar = id2 - id1 + 1;
	idxrst = indxcf_(chars + (id1 - 1), &nchar, &c__1, crst, id2 - (id1 - 
		1), (ftnlen)1);
	if (idxrst > 0) {
	    id3 = id1 + idxrst - 1;
	    ndxsup = nindxc_(chars + (id1 - 1), &idxrst, &c__1, csup, id3 - (
		    id1 - 1), (ftnlen)1);
	    ndxsub = nindxc_(chars + (id1 - 1), &idxrst, &c__1, csub, id3 - (
		    id1 - 1), (ftnlen)1);
	    if (ndxsup == 1 != (ndxsub == 1)) {
		++nctl;
		if (ndxsup == 1) {
		    idxsup = indxcf_(chars + (id1 - 1), &idxrst, &c__1, csup, 
			    id3 - (id1 - 1), (ftnlen)1);
		    nch = idxrst - idxsup - 1;
		    if (nch >= 1) {
			nsup += nch;
		    } else {
			msgdmp_("E", "SZQTXW", "NO VALID SUP CHARACTER.", (
				ftnlen)1, (ftnlen)6, (ftnlen)23);
		    }
		} else if (ndxsub == 1) {
		    idxsub = indxcf_(chars + (id1 - 1), &idxrst, &c__1, csub, 
			    id3 - (id1 - 1), (ftnlen)1);
		    nch = idxrst - idxsub - 1;
		    if (nch >= 1) {
			nsub += nch;
		    } else {
			msgdmp_("E", "SZQTXW", "NO VALID SUB CHARACTER.", (
				ftnlen)1, (ftnlen)6, (ftnlen)23);
		    }
		}
		ichk += idxrst;
	    } else {
		msgdmp_("E", "SZQTXW", "CONTROL CHARACTERS ARE NOT IN GOOD A"
			"GREEMENT.", (ftnlen)1, (ftnlen)6, (ftnlen)45);
	    }
	}
	if (! (idxrst == 0 || ichk == nchz)) {
	    goto L10;
	}
/* Computing MAX */
	r__1 = .5f, r__2 = shift + small / 2;
	dz = max(r__1,r__2) - .5f;
	rfact = 1.f;
	*wxch = 0.f;
	i__1 = nchz;
	for (n = 1; n <= i__1; ++n) {
	    ich = isgc_(chars + (n - 1), (ftnlen)1);
	    idx = ich + 1;
	    if (ich == isup || ich == isub) {
		rfact = small;
		goto L20;
	    } else if (ich == irst) {
		rfact = 1.f;
		goto L20;
	    }
	    *wxch += (wx2[idx - 1] - wx1[idx - 1]) / 24.f * rfact;
L20:
	    ;
	}
	*wych = 1.f;
	if (nsup >= 1) {
	    *wych += dz;
	}
	if (nsub >= 1) {
	    *wych += dz;
	}
    } else {
/*       / CONTROL CHARACTERS ARE NOT EFFECTIVE / */
	*wxch = 0.f;
	i__1 = nchz;
	for (n = 1; n <= i__1; ++n) {
	    idx = isgc_(chars + (n - 1), (ftnlen)1) + 1;
	    *wxch += (wx2[idx - 1] - wx1[idx - 1]) / 24.f;
/* L30: */
	}
	*wych = 1.f;
    }
    return 0;
} /* szqtxw_ */
